==> owncloud-8.2.2p3.tgz: owncloud/apps/files/l10n/nl.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Opslag niet beschikbaar",
    "Storage invalid" : "Opslag ongeldig",
    "Unknown error" : "Onbekende fout",
    "Could not move %s - File with this name already exists" : "Kon %s niet verplaatsen - Er bestaat al een bestand met deze naam",
    "Could not move %s" : "Kon %s niet verplaatsen",
    "Permission denied" : "Toegang geweigerd",
    "The target folder has been moved or deleted." : "De doelmap is verplaatst of verwijderd.",
    "The name %s is already used in the folder %s. Please choose a different name." : "De naam %s bestaat al in map %s. Kies een andere naam.",
    "Error when creating the file" : "Fout bij creëren bestand",
    "Error when creating the folder" : "Fout bij aanmaken map",
    "Unable to set upload directory." : "Kan uploadmap niet instellen.",
    "Invalid Token" : "Ongeldig Token",
    "No file was uploaded. Unknown error" : "Er was geen bestand geladen.  Onbekende fout",
    "There is no error, the file uploaded with success" : "Het bestand is succesvol geüpload.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Het geüploade bestand overscheidt de upload_max_filesize optie in php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Het bestand overschrijdt de MAX_FILE_SIZE instelling dat is opgegeven in het HTML formulier",
    "The uploaded file was only partially uploaded" : "Het bestand is slechts gedeeltelijk geüpload",
    "No file was uploaded" : "Er is geen bestand geüpload",
    "Missing a temporary folder" : "Er ontbreekt een tijdelijke map",
    "Failed to write to disk" : "Schrijven naar schijf mislukt",
    "Not enough storage available" : "Niet genoeg opslagruimte beschikbaar",
    "Upload failed. Could not find uploaded file" : "Upload mislukt. Kon geüploade bestand niet vinden",
    "Upload failed. Could not get file info." : "Upload mislukt. Kon geen bestandsinfo krijgen.",
    "Invalid directory." : "Ongeldige directory.",
    "Files" : "Bestanden",
    "All files" : "Alle bestanden",
    "Favorites" : "Favorieten",
    "Home" : "Thuis",
    "Close" : "Sluiten",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan {filename} niet uploaden omdat het een map is of 0 bytes groot is",
    "Total file size {size1} exceeds upload limit {size2}" : "Totale bestandsgrootte {size1} groter dan uploadlimiet {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Niet genoeg vrije ruimte. U upload {size1}, maar is is slechts {size2} beschikbaar",
    "Upload cancelled." : "Uploaden geannuleerd.",
    "Could not get result from server." : "Kon het resultaat van de server niet terugkrijgen.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Bestandsupload is bezig. Wanneer de pagina nu verlaten wordt, stopt de upload.",
    "Actions" : "Acties",
    "Download" : "Downloaden",
    "Rename" : "Naam wijzigen",
    "Delete" : "Verwijderen",
    "Details" : "Details",
    "Select" : "Selecteer",
    "Pending" : "In behandeling",
    "Unable to determine date" : "Kon datum niet vaststellen",
    "This operation is forbidden" : "Deze taak is verboden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Deze map is niet beschikbaar. Verifieer de logs of neem contact op met de beheerder",
    "Error moving file." : "Fout bij verplaatsen bestand.",
    "Error moving file" : "Fout bij verplaatsen bestand",
    "Error" : "Fout",
    "{new_name} already exists" : "{new_name} bestaat al",
    "Could not rename file" : "Kon de naam van het bestand niet wijzigen",
    "Could not create file" : "Kon bestand niet creëren",
    "Could not create folder" : "Kon niet creëren map",
    "Error deleting file." : "Fout bij verwijderen bestand.",
    "No entries in this folder match '{filter}'" : "Niets in deze map komt overeen met '{filter}'",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Aangepast",
    "_%n file_::_%n files_" : ["%n bestand","%n bestanden"],
    "{dirs} and {files}" : "{dirs} en {files}",
    "You don’t have permission to upload or create files here" : "U hebt geen toestemming om hier te uploaden of bestanden te maken",
    "_Uploading %n file_::_Uploading %n files_" : ["%n bestand aan het uploaden","%n bestanden aan het uploaden"],
    "New" : "Nieuw",
    "\"{name}\" is an invalid file name." : "\"{name}\" is een ongeldige bestandsnaam.",
    "File name cannot be empty." : "Bestandsnaam kan niet leeg zijn.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opslagruimte van {owner} zit vol, bestanden kunnen niet meer worden ge-upload of gesynchroniseerd!",
    "Your storage is full, files can not be updated or synced anymore!" : "Uw opslagruimte zit vol. Bestanden kunnen niet meer worden gewijzigd of gesynchroniseerd!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opslagruimte van {owner} zit bijna vol ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Uw opslagruimte zit bijna vol ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["komt overeen met '{filter}'","komen overeen met '{filter}'"],
    "Path" : "Pad",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favoriet",
    "Favorite" : "Favoriet",
    "{newname} already exists" : "{newname} bestaat al",
    "Upload" : "Uploaden",
    "Text file" : "Tekstbestand",
    "New text file.txt" : "Nieuw tekstbestand.txt",
    "Folder" : "Map",
    "New folder" : "Nieuwe map",
    "An error occurred while trying to update the tags" : "Er trad een fout op bij uw poging de tags bij te werken",
    "A new file or folder has been <strong>created</strong>" : "Een nieuw bestand of map is <strong>aangemaakt</strong>",
    "A file or folder has been <strong>changed</strong>" : "Een bestand of map is <strong>gewijzigd</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Beperk meldingen over aanmaken en wijzigen aan uw <strong>favoriete bestanden</strong> <em>(Alleen stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Een bestand of map is <strong>verwijderd</strong>",
    "A file or folder has been <strong>restored</strong>" : "Een bestand of een mmaps is <strong>hersteld</strong>",
    "You created %1$s" : "U creëerde %1$s",
    "%2$s created %1$s" : "%2$s creëerde %1$s",
    "%1$s was created in a public folder" : "%1$s werd gecreëerd in een openbare map",
    "You changed %1$s" : "U wijzigde %1$s",
    "%2$s changed %1$s" : "%2$s wijzigde %1$s",
    "You deleted %1$s" : "U verwijderde %1$s",
    "%2$s deleted %1$s" : "%2$s verwijderde %1$s",
    "You restored %1$s" : "U herstelde %1$s",
    "%2$s restored %1$s" : "%2$s herstelde %1$s",
    "Changed by %2$s" : "Gewijzigd door %2$s",
    "Deleted by %2$s" : "Verwijderd door %2$s",
    "Restored by %2$s" : "Hersteld door %2$s",
    "%s could not be renamed as it has been deleted" : "%s kon niet worden hernoemd, omdat het verwijderd is",
    "%s could not be renamed" : "%s kon niet worden hernoemd",
    "Upload (max. %s)" : "Upload (max. %s)",
    "File handling" : "Bestand",
    "Maximum upload size" : "Maximale bestandsgrootte voor uploads",
    "max. possible: " : "max. mogelijk: ",
    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "Met PHP-FPM kan het tot 5 minuten duren voordat de aanpassing van deze waarde effect heeft.",
    "Save" : "Bewaren",
    "Can not be edited from here due to insufficient permissions." : "Kan hier niet worden bewerkt wegens onvoldoende permissies.",
    "Settings" : "Instellingen",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Gebruik deze link <a href=\"%s\" target=\"_blank\">om uw bestanden via WebDAV te benaderen</a>",
    "Cancel upload" : "Upload afbreken",
    "No files in here" : "Hier geen bestanden",
    "Upload some content or sync with your devices!" : "Upload bestanden of synchroniseer met uw apparaten!",
    "No entries found in this folder" : "Niets",
    "Select all" : "Alles selecteren",
    "Upload too large" : "Upload is te groot",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "De bestanden die u probeert te uploaden zijn groter dan de maximaal toegestane  bestandsgrootte voor deze server.",
    "Files are being scanned, please wait." : "Bestanden worden gescand, even wachten.",
    "Currently scanning" : "Nu aan het scannen",
    "No favorites" : "Geen favorieten",
    "Files and folders you mark as favorite will show up here" : "Bestanden en mappen die u favoriet vindt worden hier getoont"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.4.tgz: owncloud/apps/files/l10n/nl.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Opslag niet beschikbaar",
    "Storage invalid" : "Opslag ongeldig",
    "Unknown error" : "Onbekende fout",
    "Unable to set upload directory." : "Kan uploadmap niet instellen.",
    "Invalid Token" : "Ongeldig Token",
    "No file was uploaded. Unknown error" : "Er was geen bestand geladen.  Onbekende fout",
    "There is no error, the file uploaded with success" : "Het bestand is succesvol geüpload.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Het geüploade bestand overscheidt de upload_max_filesize optie in php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Het bestand overschrijdt de MAX_FILE_SIZE instelling dat is opgegeven in het HTML formulier",
    "The uploaded file was only partially uploaded" : "Het bestand is slechts gedeeltelijk geüpload",
    "No file was uploaded" : "Er is geen bestand geüpload",
    "Missing a temporary folder" : "Er ontbreekt een tijdelijke map",
    "Failed to write to disk" : "Schrijven naar schijf mislukt",
    "Not enough storage available" : "Niet genoeg opslagruimte beschikbaar",
    "The target folder has been moved or deleted." : "De doelmap is verplaatst of verwijderd.",
    "Upload failed. Could not find uploaded file" : "Upload mislukt. Kon geüploade bestand niet vinden",
    "Upload failed. Could not get file info." : "Upload mislukt. Kon geen bestandsinfo krijgen.",
    "Invalid directory." : "Ongeldige directory.",
    "Files" : "Bestanden",
    "All files" : "Alle bestanden",
    "File could not be found" : "Bestand kon niet worden gevonden",
    "Home" : "Thuis",
    "Close" : "Sluiten",
    "Favorites" : "Favorieten",
    "Upload cancelled." : "Uploaden geannuleerd.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan {filename} niet uploaden omdat het een map is of 0 bytes groot is",
    "Total file size {size1} exceeds upload limit {size2}" : "Totale bestandsgrootte {size1} groter dan uploadlimiet {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Niet genoeg vrije ruimte. U upload {size1}, maar is is slechts {size2} beschikbaar",
    "Error uploading file \"{fileName}\": {message}" : "Fout tijdens het uploaden van bestand \"{fileName}\": {message}",
    "Could not get result from server." : "Kon het resultaat van de server niet terugkrijgen.",
    "Uploading..." : "Uploading...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Bestandsupload is bezig. Wanneer de pagina nu verlaten wordt, stopt de upload.",
    "Actions" : "Acties",
    "Download" : "Downloaden",
    "Rename" : "Naam wijzigen",
    "Delete" : "Verwijderen",
    "Disconnect storage" : "Verbinding met opslag verbreken",
    "Unshare" : "Stop met delen",
    "Details" : "Details",
    "Select" : "Selecteer",
    "Pending" : "In behandeling",
    "Unable to determine date" : "Kon datum niet vaststellen",
    "This operation is forbidden" : "Deze taak is verboden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Deze map is niet beschikbaar. Verifieer de logs of neem contact op met de beheerder",
    "Could not move \"{file}\", target exists" : "Kon \"{file}\" niet verplaatsen, doel bestaat al",
    "Could not move \"{file}\"" : "Kon \"{file}\" niet verplaatsen",
    "{newName} already exists" : "{newName} bestaat al",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kon \"{fileName}\" niet hernoemen, het bestaat niet meer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "De naam \"{targetName}\" bestaat al in map \"{dir}\". Kies een andere naam.",
    "Could not rename \"{fileName}\"" : "Kon \"{fileName}\" niet hernoemen",
    "Could not create file \"{file}\"" : "Kon \"{file}\" niet aanmaken",
    "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken, omdat het al bestaat",
    "Could not create folder \"{dir}\"" : "Kon map \"{dir}\" niet aanmaken",
    "Could not create folder \"{dir}\" because it already exists" : "Kon map \"{dir}\" niet aanmaken, omdat die al bestaat",
    "Error deleting file \"{fileName}\"." : "Fout bij verwijderen bestand \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "Niets in deze map komt overeen met '{filter}'",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Aangepast",
    "_%n file_::_%n files_" : ["%n bestand","%n bestanden"],
    "{dirs} and {files}" : "{dirs} en {files}",
    "You don’t have permission to upload or create files here" : "U hebt geen toestemming om hier te uploaden of bestanden te maken",
    "_Uploading %n file_::_Uploading %n files_" : ["%n bestand aan het uploaden","%n bestanden aan het uploaden"],
    "New" : "Nieuw",
    "\"{name}\" is an invalid file name." : "\"{name}\" is een ongeldige bestandsnaam.",
    "File name cannot be empty." : "Bestandsnaam kan niet leeg zijn.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opslagruimte van {owner} zit vol, bestanden kunnen niet meer worden ge-upload of gesynchroniseerd!",
    "Your storage is full, files can not be updated or synced anymore!" : "Uw opslagruimte zit vol. Bestanden kunnen niet meer worden gewijzigd of gesynchroniseerd!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opslagruimte van {owner} zit bijna vol ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Uw opslagruimte zit bijna vol ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["komt overeen met '{filter}'","komen overeen met '{filter}'"],
    "Path" : "Pad",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favoriet",
    "Favorite" : "Favoriet",
    "Local link" : "Lokale link",
    "Folder" : "Map",
    "New folder" : "Nieuwe map",
    "{newname} already exists" : "{newname} bestaat al",
    "Upload" : "Uploaden",
    "An error occurred while trying to update the tags" : "Er trad een fout op bij uw poging de tags bij te werken",
    "A new file or folder has been <strong>created</strong>" : "Een nieuw bestand of map is <strong>aangemaakt</strong>",
    "A file or folder has been <strong>changed</strong>" : "Een bestand of map is <strong>gewijzigd</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Beperk meldingen over aanmaken en wijzigen aan uw <strong>favoriete bestanden</strong> <em>(Alleen stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Een bestand of map is <strong>verwijderd</strong>",
    "A file or folder has been <strong>restored</strong>" : "Een bestand of een map is <strong>hersteld</strong>",
    "You created %1$s" : "Gecreëerd: %1$s",
    "%2$s created %1$s" : "%2$s creëerde %1$s",
    "%1$s was created in a public folder" : "%1$s werd gecreëerd in een openbare map",
    "You changed %1$s" : "Gewijzigd: %1$s",
    "%2$s changed %1$s" : "%2$s wijzigde %1$s",
    "You deleted %1$s" : "Verwijderd: %1$s",
    "%2$s deleted %1$s" : "%2$s verwijderde %1$s",
    "You restored %1$s" : "Hersteld: %1$s",
    "%2$s restored %1$s" : "%2$s herstelde %1$s",
    "Changed by %2$s" : "Gewijzigd door %2$s",
    "Deleted by %2$s" : "Verwijderd door %2$s",
    "Restored by %2$s" : "Hersteld door %2$s",
    "Upload (max. %s)" : "Upload (max. %s)",
    "File handling" : "Bestand",
    "Maximum upload size" : "Maximale bestandsgrootte voor uploads",
    "max. possible: " : "max. mogelijk: ",
    "Save" : "Bewaren",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Met PHP-FPM kan het 5 minuten duren voordat wijzigingen zijn doorgevoerd.",
    "Missing permissions to edit from here." : "Ontbrekende rechten om vanaf hier te bewerken.",
    "Settings" : "Instellingen",
    "Show hidden files" : "Tonen verborgen bestanden",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Gebruik deze link <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">om uw bestanden via WebDAV te benaderen</a>",
    "No files in here" : "Hier geen bestanden",
    "Upload some content or sync with your devices!" : "Upload bestanden of synchroniseer met uw apparaten!",
    "No entries found in this folder" : "Niets",
    "Select all" : "Alles selecteren",
    "Upload too large" : "Upload is te groot",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "De bestanden die u probeert te uploaden zijn groter dan de maximaal toegestane  bestandsgrootte voor deze server.",
    "No favorites" : "Geen favorieten",
    "Files and folders you mark as favorite will show up here" : "Bestanden en mappen die u favoriet vindt, worden hier getoond",
    "Text file" : "Tekstbestand",
    "New text file.txt" : "Nieuw tekstbestand.txt"
},
"nplurals=2; plural=(n != 1);");
